@@ -13,31 +13,26 @@
 
 
 SEXP anyMissing(SEXP x, SEXP idxs) {
-  SEXP ans;
   R_xlen_t nx;
 
   nx = xlength(x);
 
+  /* anyMissing() on zero-length objects should always return FALSE,
+     just like any(double(0)). */
+  if (nx == 0) return(ScalarLogical(FALSE));
+
   /* Argument 'idxs': */
   R_xlen_t nidxs;
   int idxsType;
   void *cidxs = validateIndices(idxs, nx, 1, &nidxs, &idxsType);
+  
+  if (nidxs == 0) return(ScalarLogical(FALSE));
 
-  PROTECT(ans = allocVector(LGLSXP, 1));
-  LOGICAL(ans)[0] = 0;
-
-  /* anyMissing() on zero-length objects should always return FALSE,
-     just like any(double(0)). */
-  if (nidxs == 0) {
-    UNPROTECT(1);
-    return(ans);
+  if (anyMissing_internal[idxsType](x, cidxs, nidxs)) {
+    return(ScalarLogical(TRUE));
   }
 
-  LOGICAL(ans)[0] = anyMissing_internal[idxsType](x, cidxs, nidxs);
-
-  UNPROTECT(1); /* ans */
-
-  return(ans);
+  return(ScalarLogical(FALSE));  
 } // anyMissing()
 
 
